@@ -1,5 +1,4 @@
 """Define a client to interact with the Ambient Weather APIs."""
-import logging
 from typing import Optional
 
 from aiohttp import ClientSession
@@ -7,8 +6,6 @@ from aiohttp import ClientSession
 from .api import API
 from .websocket import Websocket
 
-_LOGGER = logging.getLogger(__name__)
-
 DEFAULT_API_VERSION = 1
 
 
